"use strict";
Object.defineProperty(exports, "__esModule", {
    value: true
});
exports.default = plugin;
var _path = _interopRequireDefault(require("path"));
var _util = require("util");
var _glob = _interopRequireDefault(require("glob"));
var _reactDocgenTypescript = require("react-docgen-typescript");
function plugin(context, { src , global =false , route , tsConfig , compilerOptions , parserOptions  }) {
    return {
        name: 'docusaurus-plugin-react-docgen-typescript',
        async loadContent () {
            return getParser(tsConfig, compilerOptions, parserOptions)(await glob(Array.isArray(src) ? src.join(',') : src));
        },
        configureWebpack (config) {
            return {
                resolve: {
                    alias: {
                        '@docgen': _path.default.join(config.resolve.alias['@generated'], 'docusaurus-plugin-react-docgen-typescript', 'default')
                    }
                }
            };
        },
        async contentLoaded ({ content , actions  }) {
            const { createData , setGlobalData , addRoute  } = actions;
            if (global) {
                console.warn('Using global data can potentially slow down your entire app. Use with care ❤️');
                setGlobalData(content);
            } else if (route) {
                addRoute({
                    ...route,
                    modules: {
                        docgen: await createData('docgen.json', JSON.stringify(content))
                    }
                });
            } else {
                content.map((component)=>createData(`${component.displayName}.json`, JSON.stringify(component.props)));
            }
        }
    };
}
function _interopRequireDefault(obj) {
    return obj && obj.__esModule ? obj : {
        default: obj
    };
}
const glob = (0, _util).promisify(_glob.default);
const getParser = (config, options, parserOptions)=>{
    if (config) {
        return (0, _reactDocgenTypescript).withCustomConfig(config, parserOptions).parse;
    } else if (options) {
        return (0, _reactDocgenTypescript).withCompilerOptions(options, parserOptions).parse;
    }
    return (0, _reactDocgenTypescript).withDefaultConfig(parserOptions).parse;
};

//# sourceMappingURL=index.js.map